exceptiontools.GraceContainerError
==================================

.. abjad-lineage:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError

.. autoclass:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError.__unicode__
   :noindex:
